"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .mesaerror import MesaError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .deletebyorgapikeysbyidop import (
        DeleteByOrgAPIKeysByIDBadRequestError,
        DeleteByOrgAPIKeysByIDBadRequestErrorData,
        DeleteByOrgAPIKeysByIDConflictError,
        DeleteByOrgAPIKeysByIDConflictErrorData,
        DeleteByOrgAPIKeysByIDForbiddenError,
        DeleteByOrgAPIKeysByIDForbiddenErrorData,
        DeleteByOrgAPIKeysByIDInternalServerError,
        DeleteByOrgAPIKeysByIDInternalServerErrorData,
        DeleteByOrgAPIKeysByIDNotAcceptableError,
        DeleteByOrgAPIKeysByIDNotAcceptableErrorData,
        DeleteByOrgAPIKeysByIDNotFoundError,
        DeleteByOrgAPIKeysByIDNotFoundErrorData,
        DeleteByOrgAPIKeysByIDUnauthorizedError,
        DeleteByOrgAPIKeysByIDUnauthorizedErrorData,
    )
    from .deletebyorgbyrepobranchesbybranchop import (
        DeleteByOrgByRepoBranchesByBranchBadRequestError,
        DeleteByOrgByRepoBranchesByBranchBadRequestErrorData,
        DeleteByOrgByRepoBranchesByBranchConflictError,
        DeleteByOrgByRepoBranchesByBranchConflictErrorData,
        DeleteByOrgByRepoBranchesByBranchForbiddenError,
        DeleteByOrgByRepoBranchesByBranchForbiddenErrorData,
        DeleteByOrgByRepoBranchesByBranchInternalServerError,
        DeleteByOrgByRepoBranchesByBranchInternalServerErrorData,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableError,
        DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData,
        DeleteByOrgByRepoBranchesByBranchNotFoundError,
        DeleteByOrgByRepoBranchesByBranchNotFoundErrorData,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedError,
        DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData,
    )
    from .deletebyorgbyrepoop import (
        DeleteByOrgByRepoBadRequestError,
        DeleteByOrgByRepoBadRequestErrorData,
        DeleteByOrgByRepoConflictError,
        DeleteByOrgByRepoConflictErrorData,
        DeleteByOrgByRepoForbiddenError,
        DeleteByOrgByRepoForbiddenErrorData,
        DeleteByOrgByRepoInternalServerError,
        DeleteByOrgByRepoInternalServerErrorData,
        DeleteByOrgByRepoNotAcceptableError,
        DeleteByOrgByRepoNotAcceptableErrorData,
        DeleteByOrgByRepoNotFoundError,
        DeleteByOrgByRepoNotFoundErrorData,
        DeleteByOrgByRepoUnauthorizedError,
        DeleteByOrgByRepoUnauthorizedErrorData,
    )
    from .deletebyorgbyrepowebhooksbywebhookidop import (
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError,
        DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictError,
        DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError,
        DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError,
        DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError,
        DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError,
        DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData,
    )
    from .getbyorgapikeysop import (
        GetByOrgAPIKeysBadRequestError,
        GetByOrgAPIKeysBadRequestErrorData,
        GetByOrgAPIKeysConflictError,
        GetByOrgAPIKeysConflictErrorData,
        GetByOrgAPIKeysForbiddenError,
        GetByOrgAPIKeysForbiddenErrorData,
        GetByOrgAPIKeysInternalServerError,
        GetByOrgAPIKeysInternalServerErrorData,
        GetByOrgAPIKeysNotAcceptableError,
        GetByOrgAPIKeysNotAcceptableErrorData,
        GetByOrgAPIKeysNotFoundError,
        GetByOrgAPIKeysNotFoundErrorData,
        GetByOrgAPIKeysUnauthorizedError,
        GetByOrgAPIKeysUnauthorizedErrorData,
    )
    from .getbyorgbyrepoagentblameop import (
        GetByOrgByRepoAgentblameBadRequestError,
        GetByOrgByRepoAgentblameBadRequestErrorData,
        GetByOrgByRepoAgentblameConflictError,
        GetByOrgByRepoAgentblameConflictErrorData,
        GetByOrgByRepoAgentblameForbiddenError,
        GetByOrgByRepoAgentblameForbiddenErrorData,
        GetByOrgByRepoAgentblameInternalServerError,
        GetByOrgByRepoAgentblameInternalServerErrorData,
        GetByOrgByRepoAgentblameNotAcceptableError,
        GetByOrgByRepoAgentblameNotAcceptableErrorData,
        GetByOrgByRepoAgentblameNotFoundError,
        GetByOrgByRepoAgentblameNotFoundErrorData,
        GetByOrgByRepoAgentblameUnauthorizedError,
        GetByOrgByRepoAgentblameUnauthorizedErrorData,
    )
    from .getbyorgbyrepoanalyticsop import (
        GetByOrgByRepoAnalyticsBadRequestError,
        GetByOrgByRepoAnalyticsBadRequestErrorData,
        GetByOrgByRepoAnalyticsConflictError,
        GetByOrgByRepoAnalyticsConflictErrorData,
        GetByOrgByRepoAnalyticsForbiddenError,
        GetByOrgByRepoAnalyticsForbiddenErrorData,
        GetByOrgByRepoAnalyticsInternalServerError,
        GetByOrgByRepoAnalyticsInternalServerErrorData,
        GetByOrgByRepoAnalyticsNotAcceptableError,
        GetByOrgByRepoAnalyticsNotAcceptableErrorData,
        GetByOrgByRepoAnalyticsNotFoundError,
        GetByOrgByRepoAnalyticsNotFoundErrorData,
        GetByOrgByRepoAnalyticsUnauthorizedError,
        GetByOrgByRepoAnalyticsUnauthorizedErrorData,
    )
    from .getbyorgbyrepobranchesop import (
        GetByOrgByRepoBranchesBadRequestError,
        GetByOrgByRepoBranchesBadRequestErrorData,
        GetByOrgByRepoBranchesConflictError,
        GetByOrgByRepoBranchesConflictErrorData,
        GetByOrgByRepoBranchesForbiddenError,
        GetByOrgByRepoBranchesForbiddenErrorData,
        GetByOrgByRepoBranchesInternalServerError,
        GetByOrgByRepoBranchesInternalServerErrorData,
        GetByOrgByRepoBranchesNotAcceptableError,
        GetByOrgByRepoBranchesNotAcceptableErrorData,
        GetByOrgByRepoBranchesNotFoundError,
        GetByOrgByRepoBranchesNotFoundErrorData,
        GetByOrgByRepoBranchesUnauthorizedError,
        GetByOrgByRepoBranchesUnauthorizedErrorData,
    )
    from .getbyorgbyrepocommitsbyshaop import (
        GetByOrgByRepoCommitsByShaBadRequestError,
        GetByOrgByRepoCommitsByShaBadRequestErrorData,
        GetByOrgByRepoCommitsByShaConflictError,
        GetByOrgByRepoCommitsByShaConflictErrorData,
        GetByOrgByRepoCommitsByShaForbiddenError,
        GetByOrgByRepoCommitsByShaForbiddenErrorData,
        GetByOrgByRepoCommitsByShaInternalServerError,
        GetByOrgByRepoCommitsByShaInternalServerErrorData,
        GetByOrgByRepoCommitsByShaNotAcceptableError,
        GetByOrgByRepoCommitsByShaNotAcceptableErrorData,
        GetByOrgByRepoCommitsByShaNotFoundError,
        GetByOrgByRepoCommitsByShaNotFoundErrorData,
        GetByOrgByRepoCommitsByShaUnauthorizedError,
        GetByOrgByRepoCommitsByShaUnauthorizedErrorData,
    )
    from .getbyorgbyrepocommitsop import (
        GetByOrgByRepoCommitsBadRequestError,
        GetByOrgByRepoCommitsBadRequestErrorData,
        GetByOrgByRepoCommitsConflictError,
        GetByOrgByRepoCommitsConflictErrorData,
        GetByOrgByRepoCommitsForbiddenError,
        GetByOrgByRepoCommitsForbiddenErrorData,
        GetByOrgByRepoCommitsInternalServerError,
        GetByOrgByRepoCommitsInternalServerErrorData,
        GetByOrgByRepoCommitsNotAcceptableError,
        GetByOrgByRepoCommitsNotAcceptableErrorData,
        GetByOrgByRepoCommitsNotFoundError,
        GetByOrgByRepoCommitsNotFoundErrorData,
        GetByOrgByRepoCommitsUnauthorizedError,
        GetByOrgByRepoCommitsUnauthorizedErrorData,
    )
    from .getbyorgbyrepocontentop import (
        GetByOrgByRepoContentBadRequestError,
        GetByOrgByRepoContentBadRequestErrorData,
        GetByOrgByRepoContentConflictError,
        GetByOrgByRepoContentConflictErrorData,
        GetByOrgByRepoContentForbiddenError,
        GetByOrgByRepoContentForbiddenErrorData,
        GetByOrgByRepoContentInternalServerError,
        GetByOrgByRepoContentInternalServerErrorData,
        GetByOrgByRepoContentNotAcceptableError,
        GetByOrgByRepoContentNotAcceptableErrorData,
        GetByOrgByRepoContentNotFoundError,
        GetByOrgByRepoContentNotFoundErrorData,
        GetByOrgByRepoContentUnauthorizedError,
        GetByOrgByRepoContentUnauthorizedErrorData,
    )
    from .getbyorgbyrepodiffop import (
        GetByOrgByRepoDiffBadRequestError,
        GetByOrgByRepoDiffBadRequestErrorData,
        GetByOrgByRepoDiffConflictError,
        GetByOrgByRepoDiffConflictErrorData,
        GetByOrgByRepoDiffForbiddenError,
        GetByOrgByRepoDiffForbiddenErrorData,
        GetByOrgByRepoDiffInternalServerError,
        GetByOrgByRepoDiffInternalServerErrorData,
        GetByOrgByRepoDiffNotAcceptableError,
        GetByOrgByRepoDiffNotAcceptableErrorData,
        GetByOrgByRepoDiffNotFoundError,
        GetByOrgByRepoDiffNotFoundErrorData,
        GetByOrgByRepoDiffUnauthorizedError,
        GetByOrgByRepoDiffUnauthorizedErrorData,
    )
    from .getbyorgbyrepoop import (
        GetByOrgByRepoBadRequestError,
        GetByOrgByRepoBadRequestErrorData,
        GetByOrgByRepoConflictError,
        GetByOrgByRepoConflictErrorData,
        GetByOrgByRepoForbiddenError,
        GetByOrgByRepoForbiddenErrorData,
        GetByOrgByRepoInternalServerError,
        GetByOrgByRepoInternalServerErrorData,
        GetByOrgByRepoNotAcceptableError,
        GetByOrgByRepoNotAcceptableErrorData,
        GetByOrgByRepoNotFoundError,
        GetByOrgByRepoNotFoundErrorData,
        GetByOrgByRepoUnauthorizedError,
        GetByOrgByRepoUnauthorizedErrorData,
    )
    from .getbyorgbyreposyncop import (
        GetByOrgByRepoSyncBadRequestError,
        GetByOrgByRepoSyncBadRequestErrorData,
        GetByOrgByRepoSyncConflictError,
        GetByOrgByRepoSyncConflictErrorData,
        GetByOrgByRepoSyncForbiddenError,
        GetByOrgByRepoSyncForbiddenErrorData,
        GetByOrgByRepoSyncInternalServerError,
        GetByOrgByRepoSyncInternalServerErrorData,
        GetByOrgByRepoSyncNotAcceptableError,
        GetByOrgByRepoSyncNotAcceptableErrorData,
        GetByOrgByRepoSyncNotFoundError,
        GetByOrgByRepoSyncNotFoundErrorData,
        GetByOrgByRepoSyncUnauthorizedError,
        GetByOrgByRepoSyncUnauthorizedErrorData,
    )
    from .getbyorgbyrepowebhooksop import (
        GetByOrgByRepoWebhooksBadRequestError,
        GetByOrgByRepoWebhooksBadRequestErrorData,
        GetByOrgByRepoWebhooksConflictError,
        GetByOrgByRepoWebhooksConflictErrorData,
        GetByOrgByRepoWebhooksForbiddenError,
        GetByOrgByRepoWebhooksForbiddenErrorData,
        GetByOrgByRepoWebhooksInternalServerError,
        GetByOrgByRepoWebhooksInternalServerErrorData,
        GetByOrgByRepoWebhooksNotAcceptableError,
        GetByOrgByRepoWebhooksNotAcceptableErrorData,
        GetByOrgByRepoWebhooksNotFoundError,
        GetByOrgByRepoWebhooksNotFoundErrorData,
        GetByOrgByRepoWebhooksUnauthorizedError,
        GetByOrgByRepoWebhooksUnauthorizedErrorData,
    )
    from .getbyorgop import (
        GetByOrgBadRequestError,
        GetByOrgBadRequestErrorData,
        GetByOrgConflictError,
        GetByOrgConflictErrorData,
        GetByOrgForbiddenError,
        GetByOrgForbiddenErrorData,
        GetByOrgInternalServerError,
        GetByOrgInternalServerErrorData,
        GetByOrgNotAcceptableError,
        GetByOrgNotAcceptableErrorData,
        GetByOrgNotFoundError,
        GetByOrgNotFoundErrorData,
        GetByOrgUnauthorizedError,
        GetByOrgUnauthorizedErrorData,
    )
    from .getbyorgreposop import (
        GetByOrgReposBadRequestError,
        GetByOrgReposBadRequestErrorData,
        GetByOrgReposConflictError,
        GetByOrgReposConflictErrorData,
        GetByOrgReposForbiddenError,
        GetByOrgReposForbiddenErrorData,
        GetByOrgReposInternalServerError,
        GetByOrgReposInternalServerErrorData,
        GetByOrgReposNotAcceptableError,
        GetByOrgReposNotAcceptableErrorData,
        GetByOrgReposNotFoundError,
        GetByOrgReposNotFoundErrorData,
        GetByOrgReposUnauthorizedError,
        GetByOrgReposUnauthorizedErrorData,
    )
    from .mesadefaulterror import MesaDefaultError
    from .no_response_error import NoResponseError
    from .patchbyorgbyrepoop import (
        PatchByOrgByRepoBadRequestError,
        PatchByOrgByRepoBadRequestErrorData,
        PatchByOrgByRepoConflictError,
        PatchByOrgByRepoConflictErrorData,
        PatchByOrgByRepoForbiddenError,
        PatchByOrgByRepoForbiddenErrorData,
        PatchByOrgByRepoInternalServerError,
        PatchByOrgByRepoInternalServerErrorData,
        PatchByOrgByRepoNotAcceptableError,
        PatchByOrgByRepoNotAcceptableErrorData,
        PatchByOrgByRepoNotFoundError,
        PatchByOrgByRepoNotFoundErrorData,
        PatchByOrgByRepoUnauthorizedError,
        PatchByOrgByRepoUnauthorizedErrorData,
    )
    from .postbyorgapikeysop import (
        PostByOrgAPIKeysBadRequestError,
        PostByOrgAPIKeysBadRequestErrorData,
        PostByOrgAPIKeysConflictError,
        PostByOrgAPIKeysConflictErrorData,
        PostByOrgAPIKeysForbiddenError,
        PostByOrgAPIKeysForbiddenErrorData,
        PostByOrgAPIKeysInternalServerError,
        PostByOrgAPIKeysInternalServerErrorData,
        PostByOrgAPIKeysNotAcceptableError,
        PostByOrgAPIKeysNotAcceptableErrorData,
        PostByOrgAPIKeysNotFoundError,
        PostByOrgAPIKeysNotFoundErrorData,
        PostByOrgAPIKeysUnauthorizedError,
        PostByOrgAPIKeysUnauthorizedErrorData,
    )
    from .postbyorgbyrepoanalyticsrefreshop import (
        PostByOrgByRepoAnalyticsRefreshBadRequestError,
        PostByOrgByRepoAnalyticsRefreshBadRequestErrorData,
        PostByOrgByRepoAnalyticsRefreshConflictError,
        PostByOrgByRepoAnalyticsRefreshConflictErrorData,
        PostByOrgByRepoAnalyticsRefreshForbiddenError,
        PostByOrgByRepoAnalyticsRefreshForbiddenErrorData,
        PostByOrgByRepoAnalyticsRefreshInternalServerError,
        PostByOrgByRepoAnalyticsRefreshInternalServerErrorData,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableError,
        PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData,
        PostByOrgByRepoAnalyticsRefreshNotFoundError,
        PostByOrgByRepoAnalyticsRefreshNotFoundErrorData,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedError,
        PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData,
    )
    from .postbyorgbyrepobranchesop import (
        PostByOrgByRepoBranchesBadRequestError,
        PostByOrgByRepoBranchesBadRequestErrorData,
        PostByOrgByRepoBranchesConflictError,
        PostByOrgByRepoBranchesConflictErrorData,
        PostByOrgByRepoBranchesForbiddenError,
        PostByOrgByRepoBranchesForbiddenErrorData,
        PostByOrgByRepoBranchesInternalServerError,
        PostByOrgByRepoBranchesInternalServerErrorData,
        PostByOrgByRepoBranchesNotAcceptableError,
        PostByOrgByRepoBranchesNotAcceptableErrorData,
        PostByOrgByRepoBranchesNotFoundError,
        PostByOrgByRepoBranchesNotFoundErrorData,
        PostByOrgByRepoBranchesUnauthorizedError,
        PostByOrgByRepoBranchesUnauthorizedErrorData,
    )
    from .postbyorgbyrepocommitsop import (
        PostByOrgByRepoCommitsBadRequestError,
        PostByOrgByRepoCommitsBadRequestErrorData,
        PostByOrgByRepoCommitsConflictError,
        PostByOrgByRepoCommitsConflictErrorData,
        PostByOrgByRepoCommitsForbiddenError,
        PostByOrgByRepoCommitsForbiddenErrorData,
        PostByOrgByRepoCommitsInternalServerError,
        PostByOrgByRepoCommitsInternalServerErrorData,
        PostByOrgByRepoCommitsNotAcceptableError,
        PostByOrgByRepoCommitsNotAcceptableErrorData,
        PostByOrgByRepoCommitsNotFoundError,
        PostByOrgByRepoCommitsNotFoundErrorData,
        PostByOrgByRepoCommitsUnauthorizedError,
        PostByOrgByRepoCommitsUnauthorizedErrorData,
    )
    from .postbyorgbyreposyncop import (
        PostByOrgByRepoSyncBadRequestError,
        PostByOrgByRepoSyncBadRequestErrorData,
        PostByOrgByRepoSyncConflictError,
        PostByOrgByRepoSyncConflictErrorData,
        PostByOrgByRepoSyncForbiddenError,
        PostByOrgByRepoSyncForbiddenErrorData,
        PostByOrgByRepoSyncInternalServerError,
        PostByOrgByRepoSyncInternalServerErrorData,
        PostByOrgByRepoSyncNotAcceptableError,
        PostByOrgByRepoSyncNotAcceptableErrorData,
        PostByOrgByRepoSyncNotFoundError,
        PostByOrgByRepoSyncNotFoundErrorData,
        PostByOrgByRepoSyncUnauthorizedError,
        PostByOrgByRepoSyncUnauthorizedErrorData,
    )
    from .postbyorgbyrepowebhooksop import (
        PostByOrgByRepoWebhooksBadRequestError,
        PostByOrgByRepoWebhooksBadRequestErrorData,
        PostByOrgByRepoWebhooksConflictError,
        PostByOrgByRepoWebhooksConflictErrorData,
        PostByOrgByRepoWebhooksForbiddenError,
        PostByOrgByRepoWebhooksForbiddenErrorData,
        PostByOrgByRepoWebhooksInternalServerError,
        PostByOrgByRepoWebhooksInternalServerErrorData,
        PostByOrgByRepoWebhooksNotAcceptableError,
        PostByOrgByRepoWebhooksNotAcceptableErrorData,
        PostByOrgByRepoWebhooksNotFoundError,
        PostByOrgByRepoWebhooksNotFoundErrorData,
        PostByOrgByRepoWebhooksUnauthorizedError,
        PostByOrgByRepoWebhooksUnauthorizedErrorData,
    )
    from .postbyorgreposop import (
        PostByOrgReposBadRequestError,
        PostByOrgReposBadRequestErrorData,
        PostByOrgReposConflictError,
        PostByOrgReposConflictErrorData,
        PostByOrgReposForbiddenError,
        PostByOrgReposForbiddenErrorData,
        PostByOrgReposInternalServerError,
        PostByOrgReposInternalServerErrorData,
        PostByOrgReposNotAcceptableError,
        PostByOrgReposNotAcceptableErrorData,
        PostByOrgReposNotFoundError,
        PostByOrgReposNotFoundErrorData,
        PostByOrgReposUnauthorizedError,
        PostByOrgReposUnauthorizedErrorData,
    )
    from .responsevalidationerror import ResponseValidationError

__all__ = [
    "DeleteByOrgAPIKeysByIDBadRequestError",
    "DeleteByOrgAPIKeysByIDBadRequestErrorData",
    "DeleteByOrgAPIKeysByIDConflictError",
    "DeleteByOrgAPIKeysByIDConflictErrorData",
    "DeleteByOrgAPIKeysByIDForbiddenError",
    "DeleteByOrgAPIKeysByIDForbiddenErrorData",
    "DeleteByOrgAPIKeysByIDInternalServerError",
    "DeleteByOrgAPIKeysByIDInternalServerErrorData",
    "DeleteByOrgAPIKeysByIDNotAcceptableError",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorData",
    "DeleteByOrgAPIKeysByIDNotFoundError",
    "DeleteByOrgAPIKeysByIDNotFoundErrorData",
    "DeleteByOrgAPIKeysByIDUnauthorizedError",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorData",
    "DeleteByOrgByRepoBadRequestError",
    "DeleteByOrgByRepoBadRequestErrorData",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorData",
    "DeleteByOrgByRepoBranchesByBranchConflictError",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorData",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorData",
    "DeleteByOrgByRepoBranchesByBranchInternalServerError",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorData",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorData",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData",
    "DeleteByOrgByRepoConflictError",
    "DeleteByOrgByRepoConflictErrorData",
    "DeleteByOrgByRepoForbiddenError",
    "DeleteByOrgByRepoForbiddenErrorData",
    "DeleteByOrgByRepoInternalServerError",
    "DeleteByOrgByRepoInternalServerErrorData",
    "DeleteByOrgByRepoNotAcceptableError",
    "DeleteByOrgByRepoNotAcceptableErrorData",
    "DeleteByOrgByRepoNotFoundError",
    "DeleteByOrgByRepoNotFoundErrorData",
    "DeleteByOrgByRepoUnauthorizedError",
    "DeleteByOrgByRepoUnauthorizedErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData",
    "GetByOrgAPIKeysBadRequestError",
    "GetByOrgAPIKeysBadRequestErrorData",
    "GetByOrgAPIKeysConflictError",
    "GetByOrgAPIKeysConflictErrorData",
    "GetByOrgAPIKeysForbiddenError",
    "GetByOrgAPIKeysForbiddenErrorData",
    "GetByOrgAPIKeysInternalServerError",
    "GetByOrgAPIKeysInternalServerErrorData",
    "GetByOrgAPIKeysNotAcceptableError",
    "GetByOrgAPIKeysNotAcceptableErrorData",
    "GetByOrgAPIKeysNotFoundError",
    "GetByOrgAPIKeysNotFoundErrorData",
    "GetByOrgAPIKeysUnauthorizedError",
    "GetByOrgAPIKeysUnauthorizedErrorData",
    "GetByOrgBadRequestError",
    "GetByOrgBadRequestErrorData",
    "GetByOrgByRepoAgentblameBadRequestError",
    "GetByOrgByRepoAgentblameBadRequestErrorData",
    "GetByOrgByRepoAgentblameConflictError",
    "GetByOrgByRepoAgentblameConflictErrorData",
    "GetByOrgByRepoAgentblameForbiddenError",
    "GetByOrgByRepoAgentblameForbiddenErrorData",
    "GetByOrgByRepoAgentblameInternalServerError",
    "GetByOrgByRepoAgentblameInternalServerErrorData",
    "GetByOrgByRepoAgentblameNotAcceptableError",
    "GetByOrgByRepoAgentblameNotAcceptableErrorData",
    "GetByOrgByRepoAgentblameNotFoundError",
    "GetByOrgByRepoAgentblameNotFoundErrorData",
    "GetByOrgByRepoAgentblameUnauthorizedError",
    "GetByOrgByRepoAgentblameUnauthorizedErrorData",
    "GetByOrgByRepoAnalyticsBadRequestError",
    "GetByOrgByRepoAnalyticsBadRequestErrorData",
    "GetByOrgByRepoAnalyticsConflictError",
    "GetByOrgByRepoAnalyticsConflictErrorData",
    "GetByOrgByRepoAnalyticsForbiddenError",
    "GetByOrgByRepoAnalyticsForbiddenErrorData",
    "GetByOrgByRepoAnalyticsInternalServerError",
    "GetByOrgByRepoAnalyticsInternalServerErrorData",
    "GetByOrgByRepoAnalyticsNotAcceptableError",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorData",
    "GetByOrgByRepoAnalyticsNotFoundError",
    "GetByOrgByRepoAnalyticsNotFoundErrorData",
    "GetByOrgByRepoAnalyticsUnauthorizedError",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorData",
    "GetByOrgByRepoBadRequestError",
    "GetByOrgByRepoBadRequestErrorData",
    "GetByOrgByRepoBranchesBadRequestError",
    "GetByOrgByRepoBranchesBadRequestErrorData",
    "GetByOrgByRepoBranchesConflictError",
    "GetByOrgByRepoBranchesConflictErrorData",
    "GetByOrgByRepoBranchesForbiddenError",
    "GetByOrgByRepoBranchesForbiddenErrorData",
    "GetByOrgByRepoBranchesInternalServerError",
    "GetByOrgByRepoBranchesInternalServerErrorData",
    "GetByOrgByRepoBranchesNotAcceptableError",
    "GetByOrgByRepoBranchesNotAcceptableErrorData",
    "GetByOrgByRepoBranchesNotFoundError",
    "GetByOrgByRepoBranchesNotFoundErrorData",
    "GetByOrgByRepoBranchesUnauthorizedError",
    "GetByOrgByRepoBranchesUnauthorizedErrorData",
    "GetByOrgByRepoCommitsBadRequestError",
    "GetByOrgByRepoCommitsBadRequestErrorData",
    "GetByOrgByRepoCommitsByShaBadRequestError",
    "GetByOrgByRepoCommitsByShaBadRequestErrorData",
    "GetByOrgByRepoCommitsByShaConflictError",
    "GetByOrgByRepoCommitsByShaConflictErrorData",
    "GetByOrgByRepoCommitsByShaForbiddenError",
    "GetByOrgByRepoCommitsByShaForbiddenErrorData",
    "GetByOrgByRepoCommitsByShaInternalServerError",
    "GetByOrgByRepoCommitsByShaInternalServerErrorData",
    "GetByOrgByRepoCommitsByShaNotAcceptableError",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorData",
    "GetByOrgByRepoCommitsByShaNotFoundError",
    "GetByOrgByRepoCommitsByShaNotFoundErrorData",
    "GetByOrgByRepoCommitsByShaUnauthorizedError",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorData",
    "GetByOrgByRepoCommitsConflictError",
    "GetByOrgByRepoCommitsConflictErrorData",
    "GetByOrgByRepoCommitsForbiddenError",
    "GetByOrgByRepoCommitsForbiddenErrorData",
    "GetByOrgByRepoCommitsInternalServerError",
    "GetByOrgByRepoCommitsInternalServerErrorData",
    "GetByOrgByRepoCommitsNotAcceptableError",
    "GetByOrgByRepoCommitsNotAcceptableErrorData",
    "GetByOrgByRepoCommitsNotFoundError",
    "GetByOrgByRepoCommitsNotFoundErrorData",
    "GetByOrgByRepoCommitsUnauthorizedError",
    "GetByOrgByRepoCommitsUnauthorizedErrorData",
    "GetByOrgByRepoConflictError",
    "GetByOrgByRepoConflictErrorData",
    "GetByOrgByRepoContentBadRequestError",
    "GetByOrgByRepoContentBadRequestErrorData",
    "GetByOrgByRepoContentConflictError",
    "GetByOrgByRepoContentConflictErrorData",
    "GetByOrgByRepoContentForbiddenError",
    "GetByOrgByRepoContentForbiddenErrorData",
    "GetByOrgByRepoContentInternalServerError",
    "GetByOrgByRepoContentInternalServerErrorData",
    "GetByOrgByRepoContentNotAcceptableError",
    "GetByOrgByRepoContentNotAcceptableErrorData",
    "GetByOrgByRepoContentNotFoundError",
    "GetByOrgByRepoContentNotFoundErrorData",
    "GetByOrgByRepoContentUnauthorizedError",
    "GetByOrgByRepoContentUnauthorizedErrorData",
    "GetByOrgByRepoDiffBadRequestError",
    "GetByOrgByRepoDiffBadRequestErrorData",
    "GetByOrgByRepoDiffConflictError",
    "GetByOrgByRepoDiffConflictErrorData",
    "GetByOrgByRepoDiffForbiddenError",
    "GetByOrgByRepoDiffForbiddenErrorData",
    "GetByOrgByRepoDiffInternalServerError",
    "GetByOrgByRepoDiffInternalServerErrorData",
    "GetByOrgByRepoDiffNotAcceptableError",
    "GetByOrgByRepoDiffNotAcceptableErrorData",
    "GetByOrgByRepoDiffNotFoundError",
    "GetByOrgByRepoDiffNotFoundErrorData",
    "GetByOrgByRepoDiffUnauthorizedError",
    "GetByOrgByRepoDiffUnauthorizedErrorData",
    "GetByOrgByRepoForbiddenError",
    "GetByOrgByRepoForbiddenErrorData",
    "GetByOrgByRepoInternalServerError",
    "GetByOrgByRepoInternalServerErrorData",
    "GetByOrgByRepoNotAcceptableError",
    "GetByOrgByRepoNotAcceptableErrorData",
    "GetByOrgByRepoNotFoundError",
    "GetByOrgByRepoNotFoundErrorData",
    "GetByOrgByRepoSyncBadRequestError",
    "GetByOrgByRepoSyncBadRequestErrorData",
    "GetByOrgByRepoSyncConflictError",
    "GetByOrgByRepoSyncConflictErrorData",
    "GetByOrgByRepoSyncForbiddenError",
    "GetByOrgByRepoSyncForbiddenErrorData",
    "GetByOrgByRepoSyncInternalServerError",
    "GetByOrgByRepoSyncInternalServerErrorData",
    "GetByOrgByRepoSyncNotAcceptableError",
    "GetByOrgByRepoSyncNotAcceptableErrorData",
    "GetByOrgByRepoSyncNotFoundError",
    "GetByOrgByRepoSyncNotFoundErrorData",
    "GetByOrgByRepoSyncUnauthorizedError",
    "GetByOrgByRepoSyncUnauthorizedErrorData",
    "GetByOrgByRepoUnauthorizedError",
    "GetByOrgByRepoUnauthorizedErrorData",
    "GetByOrgByRepoWebhooksBadRequestError",
    "GetByOrgByRepoWebhooksBadRequestErrorData",
    "GetByOrgByRepoWebhooksConflictError",
    "GetByOrgByRepoWebhooksConflictErrorData",
    "GetByOrgByRepoWebhooksForbiddenError",
    "GetByOrgByRepoWebhooksForbiddenErrorData",
    "GetByOrgByRepoWebhooksInternalServerError",
    "GetByOrgByRepoWebhooksInternalServerErrorData",
    "GetByOrgByRepoWebhooksNotAcceptableError",
    "GetByOrgByRepoWebhooksNotAcceptableErrorData",
    "GetByOrgByRepoWebhooksNotFoundError",
    "GetByOrgByRepoWebhooksNotFoundErrorData",
    "GetByOrgByRepoWebhooksUnauthorizedError",
    "GetByOrgByRepoWebhooksUnauthorizedErrorData",
    "GetByOrgConflictError",
    "GetByOrgConflictErrorData",
    "GetByOrgForbiddenError",
    "GetByOrgForbiddenErrorData",
    "GetByOrgInternalServerError",
    "GetByOrgInternalServerErrorData",
    "GetByOrgNotAcceptableError",
    "GetByOrgNotAcceptableErrorData",
    "GetByOrgNotFoundError",
    "GetByOrgNotFoundErrorData",
    "GetByOrgReposBadRequestError",
    "GetByOrgReposBadRequestErrorData",
    "GetByOrgReposConflictError",
    "GetByOrgReposConflictErrorData",
    "GetByOrgReposForbiddenError",
    "GetByOrgReposForbiddenErrorData",
    "GetByOrgReposInternalServerError",
    "GetByOrgReposInternalServerErrorData",
    "GetByOrgReposNotAcceptableError",
    "GetByOrgReposNotAcceptableErrorData",
    "GetByOrgReposNotFoundError",
    "GetByOrgReposNotFoundErrorData",
    "GetByOrgReposUnauthorizedError",
    "GetByOrgReposUnauthorizedErrorData",
    "GetByOrgUnauthorizedError",
    "GetByOrgUnauthorizedErrorData",
    "MesaDefaultError",
    "MesaError",
    "NoResponseError",
    "PatchByOrgByRepoBadRequestError",
    "PatchByOrgByRepoBadRequestErrorData",
    "PatchByOrgByRepoConflictError",
    "PatchByOrgByRepoConflictErrorData",
    "PatchByOrgByRepoForbiddenError",
    "PatchByOrgByRepoForbiddenErrorData",
    "PatchByOrgByRepoInternalServerError",
    "PatchByOrgByRepoInternalServerErrorData",
    "PatchByOrgByRepoNotAcceptableError",
    "PatchByOrgByRepoNotAcceptableErrorData",
    "PatchByOrgByRepoNotFoundError",
    "PatchByOrgByRepoNotFoundErrorData",
    "PatchByOrgByRepoUnauthorizedError",
    "PatchByOrgByRepoUnauthorizedErrorData",
    "PostByOrgAPIKeysBadRequestError",
    "PostByOrgAPIKeysBadRequestErrorData",
    "PostByOrgAPIKeysConflictError",
    "PostByOrgAPIKeysConflictErrorData",
    "PostByOrgAPIKeysForbiddenError",
    "PostByOrgAPIKeysForbiddenErrorData",
    "PostByOrgAPIKeysInternalServerError",
    "PostByOrgAPIKeysInternalServerErrorData",
    "PostByOrgAPIKeysNotAcceptableError",
    "PostByOrgAPIKeysNotAcceptableErrorData",
    "PostByOrgAPIKeysNotFoundError",
    "PostByOrgAPIKeysNotFoundErrorData",
    "PostByOrgAPIKeysUnauthorizedError",
    "PostByOrgAPIKeysUnauthorizedErrorData",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorData",
    "PostByOrgByRepoAnalyticsRefreshConflictError",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorData",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorData",
    "PostByOrgByRepoAnalyticsRefreshInternalServerError",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorData",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorData",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData",
    "PostByOrgByRepoBranchesBadRequestError",
    "PostByOrgByRepoBranchesBadRequestErrorData",
    "PostByOrgByRepoBranchesConflictError",
    "PostByOrgByRepoBranchesConflictErrorData",
    "PostByOrgByRepoBranchesForbiddenError",
    "PostByOrgByRepoBranchesForbiddenErrorData",
    "PostByOrgByRepoBranchesInternalServerError",
    "PostByOrgByRepoBranchesInternalServerErrorData",
    "PostByOrgByRepoBranchesNotAcceptableError",
    "PostByOrgByRepoBranchesNotAcceptableErrorData",
    "PostByOrgByRepoBranchesNotFoundError",
    "PostByOrgByRepoBranchesNotFoundErrorData",
    "PostByOrgByRepoBranchesUnauthorizedError",
    "PostByOrgByRepoBranchesUnauthorizedErrorData",
    "PostByOrgByRepoCommitsBadRequestError",
    "PostByOrgByRepoCommitsBadRequestErrorData",
    "PostByOrgByRepoCommitsConflictError",
    "PostByOrgByRepoCommitsConflictErrorData",
    "PostByOrgByRepoCommitsForbiddenError",
    "PostByOrgByRepoCommitsForbiddenErrorData",
    "PostByOrgByRepoCommitsInternalServerError",
    "PostByOrgByRepoCommitsInternalServerErrorData",
    "PostByOrgByRepoCommitsNotAcceptableError",
    "PostByOrgByRepoCommitsNotAcceptableErrorData",
    "PostByOrgByRepoCommitsNotFoundError",
    "PostByOrgByRepoCommitsNotFoundErrorData",
    "PostByOrgByRepoCommitsUnauthorizedError",
    "PostByOrgByRepoCommitsUnauthorizedErrorData",
    "PostByOrgByRepoSyncBadRequestError",
    "PostByOrgByRepoSyncBadRequestErrorData",
    "PostByOrgByRepoSyncConflictError",
    "PostByOrgByRepoSyncConflictErrorData",
    "PostByOrgByRepoSyncForbiddenError",
    "PostByOrgByRepoSyncForbiddenErrorData",
    "PostByOrgByRepoSyncInternalServerError",
    "PostByOrgByRepoSyncInternalServerErrorData",
    "PostByOrgByRepoSyncNotAcceptableError",
    "PostByOrgByRepoSyncNotAcceptableErrorData",
    "PostByOrgByRepoSyncNotFoundError",
    "PostByOrgByRepoSyncNotFoundErrorData",
    "PostByOrgByRepoSyncUnauthorizedError",
    "PostByOrgByRepoSyncUnauthorizedErrorData",
    "PostByOrgByRepoWebhooksBadRequestError",
    "PostByOrgByRepoWebhooksBadRequestErrorData",
    "PostByOrgByRepoWebhooksConflictError",
    "PostByOrgByRepoWebhooksConflictErrorData",
    "PostByOrgByRepoWebhooksForbiddenError",
    "PostByOrgByRepoWebhooksForbiddenErrorData",
    "PostByOrgByRepoWebhooksInternalServerError",
    "PostByOrgByRepoWebhooksInternalServerErrorData",
    "PostByOrgByRepoWebhooksNotAcceptableError",
    "PostByOrgByRepoWebhooksNotAcceptableErrorData",
    "PostByOrgByRepoWebhooksNotFoundError",
    "PostByOrgByRepoWebhooksNotFoundErrorData",
    "PostByOrgByRepoWebhooksUnauthorizedError",
    "PostByOrgByRepoWebhooksUnauthorizedErrorData",
    "PostByOrgReposBadRequestError",
    "PostByOrgReposBadRequestErrorData",
    "PostByOrgReposConflictError",
    "PostByOrgReposConflictErrorData",
    "PostByOrgReposForbiddenError",
    "PostByOrgReposForbiddenErrorData",
    "PostByOrgReposInternalServerError",
    "PostByOrgReposInternalServerErrorData",
    "PostByOrgReposNotAcceptableError",
    "PostByOrgReposNotAcceptableErrorData",
    "PostByOrgReposNotFoundError",
    "PostByOrgReposNotFoundErrorData",
    "PostByOrgReposUnauthorizedError",
    "PostByOrgReposUnauthorizedErrorData",
    "ResponseValidationError",
]

_dynamic_imports: dict[str, str] = {
    "DeleteByOrgAPIKeysByIDBadRequestError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDBadRequestErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDConflictErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDForbiddenErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDInternalServerErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotAcceptableErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDNotFoundErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedError": ".deletebyorgapikeysbyidop",
    "DeleteByOrgAPIKeysByIDUnauthorizedErrorData": ".deletebyorgapikeysbyidop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchBadRequestErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchConflictErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchForbiddenErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchInternalServerErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchNotFoundErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedError": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData": ".deletebyorgbyrepobranchesbybranchop",
    "DeleteByOrgByRepoBadRequestError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoBadRequestErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoConflictErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoForbiddenErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoInternalServerErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotAcceptableErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoNotFoundErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedError": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoUnauthorizedErrorData": ".deletebyorgbyrepoop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDBadRequestErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDConflictErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDForbiddenErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDInternalServerErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotAcceptableErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDNotFoundErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedError": ".deletebyorgbyrepowebhooksbywebhookidop",
    "DeleteByOrgByRepoWebhooksByWebhookIDUnauthorizedErrorData": ".deletebyorgbyrepowebhooksbywebhookidop",
    "GetByOrgAPIKeysBadRequestError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysBadRequestErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysConflictErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysForbiddenErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysInternalServerErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotAcceptableErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysNotFoundErrorData": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedError": ".getbyorgapikeysop",
    "GetByOrgAPIKeysUnauthorizedErrorData": ".getbyorgapikeysop",
    "GetByOrgByRepoAgentblameBadRequestError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameBadRequestErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameConflictErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameForbiddenErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameInternalServerErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotAcceptableErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameNotFoundErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedError": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAgentblameUnauthorizedErrorData": ".getbyorgbyrepoagentblameop",
    "GetByOrgByRepoAnalyticsBadRequestError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsBadRequestErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsConflictErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsForbiddenErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsInternalServerErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotAcceptableErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsNotFoundErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedError": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoAnalyticsUnauthorizedErrorData": ".getbyorgbyrepoanalyticsop",
    "GetByOrgByRepoBranchesBadRequestError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesBadRequestErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesConflictErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesForbiddenErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesInternalServerErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotAcceptableErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesNotFoundErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedError": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoBranchesUnauthorizedErrorData": ".getbyorgbyrepobranchesop",
    "GetByOrgByRepoCommitsByShaBadRequestError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaBadRequestErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaConflictErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaForbiddenErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaInternalServerErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotAcceptableErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaNotFoundErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedError": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsByShaUnauthorizedErrorData": ".getbyorgbyrepocommitsbyshaop",
    "GetByOrgByRepoCommitsBadRequestError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsBadRequestErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsConflictErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsForbiddenErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsInternalServerErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotAcceptableErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsNotFoundErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedError": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoCommitsUnauthorizedErrorData": ".getbyorgbyrepocommitsop",
    "GetByOrgByRepoContentBadRequestError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentBadRequestErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentConflictErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentForbiddenErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentInternalServerErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotAcceptableErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentNotFoundErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedError": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoContentUnauthorizedErrorData": ".getbyorgbyrepocontentop",
    "GetByOrgByRepoDiffBadRequestError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffBadRequestErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffConflictErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffForbiddenErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffInternalServerErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotAcceptableErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffNotFoundErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedError": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoDiffUnauthorizedErrorData": ".getbyorgbyrepodiffop",
    "GetByOrgByRepoBadRequestError": ".getbyorgbyrepoop",
    "GetByOrgByRepoBadRequestErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictError": ".getbyorgbyrepoop",
    "GetByOrgByRepoConflictErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenError": ".getbyorgbyrepoop",
    "GetByOrgByRepoForbiddenErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerError": ".getbyorgbyrepoop",
    "GetByOrgByRepoInternalServerErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotAcceptableErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundError": ".getbyorgbyrepoop",
    "GetByOrgByRepoNotFoundErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedError": ".getbyorgbyrepoop",
    "GetByOrgByRepoUnauthorizedErrorData": ".getbyorgbyrepoop",
    "GetByOrgByRepoSyncBadRequestError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncBadRequestErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncConflictErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncForbiddenErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncInternalServerErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotAcceptableErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncNotFoundErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedError": ".getbyorgbyreposyncop",
    "GetByOrgByRepoSyncUnauthorizedErrorData": ".getbyorgbyreposyncop",
    "GetByOrgByRepoWebhooksBadRequestError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksBadRequestErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksConflictErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksForbiddenErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksInternalServerErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotAcceptableErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksNotFoundErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedError": ".getbyorgbyrepowebhooksop",
    "GetByOrgByRepoWebhooksUnauthorizedErrorData": ".getbyorgbyrepowebhooksop",
    "GetByOrgBadRequestError": ".getbyorgop",
    "GetByOrgBadRequestErrorData": ".getbyorgop",
    "GetByOrgConflictError": ".getbyorgop",
    "GetByOrgConflictErrorData": ".getbyorgop",
    "GetByOrgForbiddenError": ".getbyorgop",
    "GetByOrgForbiddenErrorData": ".getbyorgop",
    "GetByOrgInternalServerError": ".getbyorgop",
    "GetByOrgInternalServerErrorData": ".getbyorgop",
    "GetByOrgNotAcceptableError": ".getbyorgop",
    "GetByOrgNotAcceptableErrorData": ".getbyorgop",
    "GetByOrgNotFoundError": ".getbyorgop",
    "GetByOrgNotFoundErrorData": ".getbyorgop",
    "GetByOrgUnauthorizedError": ".getbyorgop",
    "GetByOrgUnauthorizedErrorData": ".getbyorgop",
    "GetByOrgReposBadRequestError": ".getbyorgreposop",
    "GetByOrgReposBadRequestErrorData": ".getbyorgreposop",
    "GetByOrgReposConflictError": ".getbyorgreposop",
    "GetByOrgReposConflictErrorData": ".getbyorgreposop",
    "GetByOrgReposForbiddenError": ".getbyorgreposop",
    "GetByOrgReposForbiddenErrorData": ".getbyorgreposop",
    "GetByOrgReposInternalServerError": ".getbyorgreposop",
    "GetByOrgReposInternalServerErrorData": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableError": ".getbyorgreposop",
    "GetByOrgReposNotAcceptableErrorData": ".getbyorgreposop",
    "GetByOrgReposNotFoundError": ".getbyorgreposop",
    "GetByOrgReposNotFoundErrorData": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedError": ".getbyorgreposop",
    "GetByOrgReposUnauthorizedErrorData": ".getbyorgreposop",
    "MesaDefaultError": ".mesadefaulterror",
    "NoResponseError": ".no_response_error",
    "PatchByOrgByRepoBadRequestError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoBadRequestErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoConflictErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoForbiddenErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoInternalServerErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotAcceptableErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoNotFoundErrorData": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedError": ".patchbyorgbyrepoop",
    "PatchByOrgByRepoUnauthorizedErrorData": ".patchbyorgbyrepoop",
    "PostByOrgAPIKeysBadRequestError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysBadRequestErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysConflictErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysForbiddenErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysInternalServerErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotAcceptableErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysNotFoundErrorData": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedError": ".postbyorgapikeysop",
    "PostByOrgAPIKeysUnauthorizedErrorData": ".postbyorgapikeysop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshBadRequestErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshConflictErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshForbiddenErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshInternalServerErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotAcceptableErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshNotFoundErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedError": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoAnalyticsRefreshUnauthorizedErrorData": ".postbyorgbyrepoanalyticsrefreshop",
    "PostByOrgByRepoBranchesBadRequestError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesBadRequestErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesConflictErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesForbiddenErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesInternalServerErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotAcceptableErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesNotFoundErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedError": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoBranchesUnauthorizedErrorData": ".postbyorgbyrepobranchesop",
    "PostByOrgByRepoCommitsBadRequestError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsBadRequestErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsConflictErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsForbiddenErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsInternalServerErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotAcceptableErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsNotFoundErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedError": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoCommitsUnauthorizedErrorData": ".postbyorgbyrepocommitsop",
    "PostByOrgByRepoSyncBadRequestError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncBadRequestErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncConflictErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncForbiddenErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncInternalServerErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotAcceptableErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncNotFoundErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedError": ".postbyorgbyreposyncop",
    "PostByOrgByRepoSyncUnauthorizedErrorData": ".postbyorgbyreposyncop",
    "PostByOrgByRepoWebhooksBadRequestError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksBadRequestErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksConflictErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksForbiddenErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksInternalServerErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotAcceptableErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksNotFoundErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedError": ".postbyorgbyrepowebhooksop",
    "PostByOrgByRepoWebhooksUnauthorizedErrorData": ".postbyorgbyrepowebhooksop",
    "PostByOrgReposBadRequestError": ".postbyorgreposop",
    "PostByOrgReposBadRequestErrorData": ".postbyorgreposop",
    "PostByOrgReposConflictError": ".postbyorgreposop",
    "PostByOrgReposConflictErrorData": ".postbyorgreposop",
    "PostByOrgReposForbiddenError": ".postbyorgreposop",
    "PostByOrgReposForbiddenErrorData": ".postbyorgreposop",
    "PostByOrgReposInternalServerError": ".postbyorgreposop",
    "PostByOrgReposInternalServerErrorData": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableError": ".postbyorgreposop",
    "PostByOrgReposNotAcceptableErrorData": ".postbyorgreposop",
    "PostByOrgReposNotFoundError": ".postbyorgreposop",
    "PostByOrgReposNotFoundErrorData": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedError": ".postbyorgreposop",
    "PostByOrgReposUnauthorizedErrorData": ".postbyorgreposop",
    "ResponseValidationError": ".responsevalidationerror",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyreposyncop as models_getbyorgbyreposyncop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoSyncInternalServerErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoSyncInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncConflictErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoSyncConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoSyncNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncNotFoundErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoSyncNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncForbiddenErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoSyncForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoSyncUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoSyncBadRequestErrorData(BaseModel):
    error: models_getbyorgbyreposyncop.GetByOrgByRepoSyncBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoSyncBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoSyncBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoSyncBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostByOrgByRepoBranchesRequestBodyTypedDict(TypedDict):
    name: str
    from_: str


class PostByOrgByRepoBranchesRequestBody(BaseModel):
    name: str

    from_: Annotated[str, pydantic.Field(alias="from")]


class PostByOrgByRepoBranchesRequestTypedDict(TypedDict):
    org: str
    repo: str
    body: NotRequired[PostByOrgByRepoBranchesRequestBodyTypedDict]


class PostByOrgByRepoBranchesRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    body: Annotated[
        Optional[PostByOrgByRepoBranchesRequestBody],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class PostByOrgByRepoBranchesBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class PostByOrgByRepoBranchesResponseTypedDict(TypedDict):
    r"""Branch created"""

    name: str
    head_sha: str
    is_default: bool


class PostByOrgByRepoBranchesResponse(BaseModel):
    r"""Branch created"""

    name: str

    head_sha: str

    is_default: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Any, Awaitable, Callable, Dict, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgByRepoBranchesRequestTypedDict(TypedDict):
    org: str
    repo: str
    cursor: NotRequired[str]
    limit: NotRequired[int]


class GetByOrgByRepoBranchesRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cursor", "limit"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoBranchesBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoBranchesBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class BranchTypedDict(TypedDict):
    name: str
    head_sha: str
    is_default: bool


class Branch(BaseModel):
    name: str

    head_sha: str

    is_default: bool


class GetByOrgByRepoBranchesResponseBodyTypedDict(TypedDict):
    r"""Branch list"""

    next_cursor: Nullable[str]
    has_more: bool
    branches: List[BranchTypedDict]


class GetByOrgByRepoBranchesResponseBody(BaseModel):
    r"""Branch list"""

    next_cursor: Nullable[str]

    has_more: bool

    branches: List[Branch]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgByRepoBranchesResponseTypedDict(TypedDict):
    result: GetByOrgByRepoBranchesResponseBodyTypedDict


class GetByOrgByRepoBranchesResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetByOrgByRepoBranchesResponse]],
        Callable[[], Awaitable[Optional[GetByOrgByRepoBranchesResponse]]],
    ]

    result: GetByOrgByRepoBranchesResponseBody



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, UNSET_SENTINEL, UnrecognizedStr
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class GetByOrgByRepoDiffRequestTypedDict(TypedDict):
    org: str
    repo: str
    base: str
    head: str


class GetByOrgByRepoDiffRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    base: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    head: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class GetByOrgByRepoDiffInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoDiffBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffStatsTypedDict(TypedDict):
    files: float
    additions: float
    deletions: float
    changes: float


class GetByOrgByRepoDiffStats(BaseModel):
    files: float

    additions: float

    deletions: float

    changes: float


FileStatus = Union[
    Literal[
        "A",
        "M",
        "D",
        "R",
        "C",
        "T",
    ],
    UnrecognizedStr,
]


class GetByOrgByRepoDiffFileTypedDict(TypedDict):
    path: str
    status: FileStatus
    old_path: NotRequired[str]
    bytes_: NotRequired[float]
    is_eof: NotRequired[bool]
    raw: NotRequired[str]


class GetByOrgByRepoDiffFile(BaseModel):
    path: str

    status: FileStatus

    old_path: Optional[str] = None

    bytes_: Annotated[Optional[float], pydantic.Field(alias="bytes")] = None

    is_eof: Optional[bool] = None

    raw: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["old_path", "bytes", "is_eof", "raw"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


FilteredFileStatus = Union[
    Literal[
        "A",
        "M",
        "D",
        "R",
        "C",
        "T",
    ],
    UnrecognizedStr,
]


class FilteredFileTypedDict(TypedDict):
    path: str
    status: FilteredFileStatus
    old_path: NotRequired[str]
    bytes_: NotRequired[float]
    is_eof: NotRequired[bool]


class FilteredFile(BaseModel):
    path: str

    status: FilteredFileStatus

    old_path: Optional[str] = None

    bytes_: Annotated[Optional[float], pydantic.Field(alias="bytes")] = None

    is_eof: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["old_path", "bytes", "is_eof"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoDiffResponseBodyTypedDict(TypedDict):
    r"""Diff response"""

    base: str
    head: str
    stats: GetByOrgByRepoDiffStatsTypedDict
    files: List[GetByOrgByRepoDiffFileTypedDict]
    filtered_files: List[FilteredFileTypedDict]


class GetByOrgByRepoDiffResponseBody(BaseModel):
    r"""Diff response"""

    base: str

    head: str

    stats: GetByOrgByRepoDiffStats

    files: List[GetByOrgByRepoDiffFile]

    filtered_files: List[FilteredFile]


GetByOrgByRepoDiffResponseTypedDict = TypeAliasType(
    "GetByOrgByRepoDiffResponseTypedDict",
    Union[GetByOrgByRepoDiffResponseBodyTypedDict, str],
)


GetByOrgByRepoDiffResponse = TypeAliasType(
    "GetByOrgByRepoDiffResponse", Union[GetByOrgByRepoDiffResponseBody, str]
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    getbyorgbyrepocommitsbyshaop as models_getbyorgbyrepocommitsbyshaop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoCommitsByShaInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoCommitsByShaInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaConflictErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoCommitsByShaConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaNotAcceptableErrorData(BaseModel):
    error: (
        models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaNotAcceptableError
    )


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoCommitsByShaNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoCommitsByShaNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoCommitsByShaForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaUnauthorizedErrorData(BaseModel):
    error: (
        models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaUnauthorizedError
    )


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoCommitsByShaUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoCommitsByShaBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepocommitsbyshaop.GetByOrgByRepoCommitsByShaBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoCommitsByShaBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoCommitsByShaBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoCommitsByShaBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgByRepoAgentblameRequestTypedDict(TypedDict):
    org: str
    repo: str
    base: str
    head: str


class GetByOrgByRepoAgentblameRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    repo: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    base: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]

    head: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class GetByOrgByRepoAgentblameInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgByRepoAgentblameBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgByRepoAgentblameBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class AttributionTypedDict(TypedDict):
    line_number: float
    provider: str
    model: Nullable[str]
    confidence: float
    match_type: str


class Attribution(BaseModel):
    line_number: Annotated[float, pydantic.Field(alias="lineNumber")]

    provider: str

    model: Nullable[str]

    confidence: float

    match_type: str

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgByRepoAgentblameStatsTypedDict(TypedDict):
    total_lines: float
    ai_lines: float
    human_lines: float
    ai_percentage: float


class GetByOrgByRepoAgentblameStats(BaseModel):
    total_lines: float

    ai_lines: float

    human_lines: float

    ai_percentage: float


class GetByOrgByRepoAgentblameResponseTypedDict(TypedDict):
    r"""Attribution data"""

    attributions: Dict[str, List[AttributionTypedDict]]
    stats: GetByOrgByRepoAgentblameStatsTypedDict


class GetByOrgByRepoAgentblameResponse(BaseModel):
    r"""Attribution data"""

    attributions: Dict[str, List[Attribution]]

    stats: GetByOrgByRepoAgentblameStats



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import (
    deletebyorgbyrepobranchesbybranchop as models_deletebyorgbyrepobranchesbybranchop,
)
from mesa_sdk.types import BaseModel
from typing import Optional


class DeleteByOrgByRepoBranchesByBranchInternalServerErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchInternalServerErrorError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchInternalServerError(MesaError):
    r"""Internal error"""

    data: DeleteByOrgByRepoBranchesByBranchInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchConflictErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchConflictError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchConflictError(MesaError):
    r"""Conflict"""

    data: DeleteByOrgByRepoBranchesByBranchConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchNotAcceptableError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchNotFoundErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchNotFoundError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchNotFoundError(MesaError):
    r"""Not found"""

    data: DeleteByOrgByRepoBranchesByBranchNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchForbiddenErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchForbiddenError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchForbiddenError(MesaError):
    r"""Forbidden"""

    data: DeleteByOrgByRepoBranchesByBranchForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchUnauthorizedError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class DeleteByOrgByRepoBranchesByBranchBadRequestErrorData(BaseModel):
    error: models_deletebyorgbyrepobranchesbybranchop.DeleteByOrgByRepoBranchesByBranchBadRequestError


@dataclass(unsafe_hash=True)
class DeleteByOrgByRepoBranchesByBranchBadRequestError(MesaError):
    r"""Invalid request"""

    data: DeleteByOrgByRepoBranchesByBranchBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: DeleteByOrgByRepoBranchesByBranchBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mesa_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from mesa_sdk.utils import FieldMetadata, PathParamMetadata
from pydantic import model_serializer
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetByOrgAPIKeysRequestTypedDict(TypedDict):
    org: str


class GetByOrgAPIKeysRequest(BaseModel):
    org: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GetByOrgAPIKeysInternalServerErrorErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysInternalServerErrorError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysConflictErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysConflictError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysNotAcceptableErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysNotAcceptableError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysNotFoundErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysNotFoundError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysForbiddenErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysForbiddenError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysUnauthorizedErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysUnauthorizedError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetByOrgAPIKeysBadRequestErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[Dict[str, Any]]


class GetByOrgAPIKeysBadRequestError(BaseModel):
    code: str

    message: str

    details: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["details"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class APIKeyTypedDict(TypedDict):
    id: str
    name: Nullable[str]
    scopes: List[str]
    last_used_at: Nullable[str]
    expires_at: Nullable[str]
    revoked_at: Nullable[str]
    created_at: str


class APIKey(BaseModel):
    id: str

    name: Nullable[str]

    scopes: List[str]

    last_used_at: Nullable[str]

    expires_at: Nullable[str]

    revoked_at: Nullable[str]

    created_at: str

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                m[k] = val

        return m


class GetByOrgAPIKeysResponseTypedDict(TypedDict):
    r"""API keys list"""

    api_keys: List[APIKeyTypedDict]


class GetByOrgAPIKeysResponse(BaseModel):
    r"""API keys list"""

    api_keys: List[APIKey]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgreposop as models_getbyorgreposop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgReposInternalServerErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgReposInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgReposInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposConflictErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposConflictError


@dataclass(unsafe_hash=True)
class GetByOrgReposConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgReposConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposNotAcceptableErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgReposNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgReposNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposNotFoundErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgReposNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgReposNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposForbiddenErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgReposForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgReposForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposUnauthorizedErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgReposUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgReposUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgReposBadRequestErrorData(BaseModel):
    error: models_getbyorgreposop.GetByOrgReposBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgReposBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgReposBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgReposBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from mesa_sdk.errors import MesaError
from mesa_sdk.models import getbyorgbyrepocontentop as models_getbyorgbyrepocontentop
from mesa_sdk.types import BaseModel
from typing import Optional


class GetByOrgByRepoContentInternalServerErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentInternalServerErrorError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentInternalServerError(MesaError):
    r"""Internal error"""

    data: GetByOrgByRepoContentInternalServerErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentConflictErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentConflictError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentConflictError(MesaError):
    r"""Conflict"""

    data: GetByOrgByRepoContentConflictErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentConflictErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentNotAcceptableErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentNotAcceptableError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentNotAcceptableError(MesaError):
    r"""Not acceptable"""

    data: GetByOrgByRepoContentNotAcceptableErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentNotAcceptableErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentNotFoundErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentNotFoundError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentNotFoundError(MesaError):
    r"""Not found"""

    data: GetByOrgByRepoContentNotFoundErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentForbiddenErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentForbiddenError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentForbiddenError(MesaError):
    r"""Forbidden"""

    data: GetByOrgByRepoContentForbiddenErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentForbiddenErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentUnauthorizedErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentUnauthorizedError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentUnauthorizedError(MesaError):
    r"""Unauthorized"""

    data: GetByOrgByRepoContentUnauthorizedErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentUnauthorizedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)


class GetByOrgByRepoContentBadRequestErrorData(BaseModel):
    error: models_getbyorgbyrepocontentop.GetByOrgByRepoContentBadRequestError


@dataclass(unsafe_hash=True)
class GetByOrgByRepoContentBadRequestError(MesaError):
    r"""Invalid request"""

    data: GetByOrgByRepoContentBadRequestErrorData = field(hash=False)

    def __init__(
        self,
        data: GetByOrgByRepoContentBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
